==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Főoldal', # MODIF
	'articles' => 'Cikkek',
	'articles_auteur' => 'E szerző cikkei',
	'articles_populaires' => 'Legnépszerűbb cikkek',
	'articles_rubrique' => 'A rovat cikkei',
	'aucun_article' => '<NENincs cikke ezen a címen',
	'aucun_auteur' => 'Nincs szerző ezen a címen',
	'aucun_site' => 'Nincs honlap ezen a címen',
	'aucune_breve' => 'Nincs hír ezen a címen',
	'aucune_rubrique' => 'Nincs rovat ezen a címen',
	'autres_breves' => 'Egyéb hírek',
	'autres_groupes_mots_clefs' => 'Egyéb kulcsszó csoportok',
	'autres_sites' => 'Egyéb honlapok',

	// B
	'bonjour' => 'Jó napot',

	// C
	'commenter_site' => 'Hozzászólás a honlapról',

	// D
	'date' => 'Dátum',
	'dernier_ajout' => 'Utolsó beszúrás',
	'dernieres_breves' => 'Utolsó hírek',
	'derniers_articles' => 'Utolsó cikkek',
	'derniers_commentaires' => 'Utolsó hozzászólások',
	'derniers_messages_forum' => 'A fórumokba küldött legutolsó üzenetek',

	// E
	'edition_mode_texte' => 'Szöveges módban szerkesztés',
	'en_reponse' => 'Erre válaszolva :',
	'en_resume' => 'Összefoglalva',
	'envoyer_message' => 'Üzenet küldés',
	'espace_prive' => 'Privát rész',

	// H
	'hierarchie_site' => 'A honlap felépítése',

	// J
	'jours' => 'napok',

	// M
	'meme_auteur' => 'Ugyanettől a szerzőtől',
	'meme_rubrique' => 'Ugyanabban a rovatban',
	'memes_auteurs' => 'Ugyanettől a szerzőktől',
	'message' => 'Üzenet',
	'messages_forum' => 'Fórum üzenetei', # MODIF
	'messages_recents' => 'A fórumok legfríssebb üzenetei',
	'mots_clefs' => 'Kulcsszavak',
	'mots_clefs_meme_groupe' => 'Kulcsszavak ugyanabban a csoportban',

	// N
	'navigation' => 'Böngészés',
	'nom' => 'Név',
	'nouveautes' => 'Újdonságok',
	'nouveautes_web' => 'Újdonságok a Weben',
	'nouveaux_articles' => 'Új cikkek',
	'nouvelles_breves' => 'Új hírek',

	// P
	'page_precedente' => 'Elöző oldal',
	'page_suivante' => 'következő oldal',
	'par_auteur' => 'írta',
	'participer_site' => 'Részt vehet a honlap életében, és saját cikkeket küldhet. Azért egy beiratkozás szükséges (lásd lejjebb). Azonnal fog kapni egy emailt, melyben szerepelnek a hozzáférési paraméterek a honlap privát részére.',
	'plan_site' => 'Honlap térképe',
	'popularite' => 'Népszerűség',
	'poster_message' => 'Üzenet küldés',
	'proposer_site' => 'Honlapot ajánlhat abban a rovatban :',

	// R
	'repondre_article' => 'Hozzászólás a cikkhez',
	'repondre_breve' => 'Válaszolni erre a hírre',
	'resultats_recherche' => 'Keresés eredményei',
	'retour_debut_forums' => 'Vissza a fórumok kezdetére',
	'rubrique' => 'Rovat',
	'rubriques' => 'Rovatok',

	// S
	'signatures_petition' => 'Aláírások',
	'site_realise_avec_spip' => 'A honlap SPIP segítségével készült',
	'sites_web' => 'Honlapok',
	'sous_rubriques' => 'Alsóbb rovatok',
	'suite' => 'folytatás',
	'sur_web' => 'Valahol a Weben',
	'syndiquer_rubrique' => 'A rovat szindikálása',
	'syndiquer_site' => 'Az egész honlap szindikálása',

	// T
	'texte_lettre_information' => 'Íme a honlap hírlevele',
	'texte_lettre_information_2' => 'Ez a hírlevél a cikkeket, ill. híreket összefoglalja azóta', # MODIF

	// V
	'ver_imprimer' => 'Nyomtatható változat',
	'voir_en_ligne' => 'Látni élőben'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=hu
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Főoldal', # MODIF
	'articles' => 'Cikkek',
	'articles_auteur' => 'E szerző cikkei',
	'articles_populaires' => 'Legnépszerűbb cikkek',
	'articles_rubrique' => 'A rovat cikkei',
	'aucun_article' => '<NENincs cikke ezen a címen',
	'aucun_auteur' => 'Nincs szerző ezen a címen',
	'aucun_site' => 'Nincs honlap ezen a címen',
	'aucune_breve' => 'Nincs hír ezen a címen',
	'aucune_rubrique' => 'Nincs rovat ezen a címen',
	'autres_breves' => 'Egyéb hírek',
	'autres_groupes_mots_clefs' => 'Egyéb kulcsszó csoportok',
	'autres_sites' => 'Egyéb honlapok',

	// B
	'bonjour' => 'Jó napot',

	// C
	'commenter_site' => 'Hozzászólás a honlapról',

	// D
	'date' => 'Dátum',
	'dernier_ajout' => 'Utolsó beszúrás',
	'dernieres_breves' => 'Utolsó hírek',
	'derniers_articles' => 'Utolsó cikkek',
	'derniers_commentaires' => 'Utolsó hozzászólások',
	'derniers_messages_forum' => 'A fórumokba küldött legutolsó üzenetek',

	// E
	'edition_mode_texte' => 'Szöveges módban szerkesztés',
	'en_reponse' => 'Erre válaszolva :',
	'en_resume' => 'Összefoglalva',
	'envoyer_message' => 'Üzenet küldés',
	'espace_prive' => 'Privát rész',

	// H
	'hierarchie_site' => 'A honlap felépítése',

	// J
	'jours' => 'napok',

	// M
	'meme_auteur' => 'Ugyanettől a szerzőtől',
	'meme_rubrique' => 'Ugyanabban a rovatban',
	'memes_auteurs' => 'Ugyanettől a szerzőktől',
	'message' => 'Üzenet',
	'messages_forum' => 'Fórum üzenetei', # MODIF
	'messages_recents' => 'A fórumok legfríssebb üzenetei',
	'mots_clefs' => 'Kulcsszavak',
	'mots_clefs_meme_groupe' => 'Kulcsszavak ugyanabban a csoportban',

	// N
	'navigation' => 'Böngészés',
	'nom' => 'Név',
	'nouveautes' => 'Újdonságok',
	'nouveautes_web' => 'Újdonságok a Weben',
	'nouveaux_articles' => 'Új cikkek',
	'nouvelles_breves' => 'Új hírek',

	// P
	'page_precedente' => 'Elöző oldal',
	'page_suivante' => 'következő oldal',
	'par_auteur' => 'írta',
	'participer_site' => 'Részt vehet a honlap életében, és saját cikkeket küldhet. Azért egy beiratkozás szükséges (lásd lejjebb). Azonnal fog kapni egy emailt, melyben szerepelnek a hozzáférési paraméterek a honlap privát részére.',
	'plan_site' => 'Honlap térképe',
	'popularite' => 'Népszerűség',
	'poster_message' => 'Üzenet küldés',
	'proposer_site' => 'Honlapot ajánlhat abban a rovatban :',

	// R
	'repondre_article' => 'Hozzászólás a cikkhez',
	'repondre_breve' => 'Válaszolni erre a hírre',
	'resultats_recherche' => 'Keresés eredményei',
	'retour_debut_forums' => 'Vissza a fórumok kezdetére',
	'rubrique' => 'Rovat',
	'rubriques' => 'Rovatok',

	// S
	'signatures_petition' => 'Aláírások',
	'site_realise_avec_spip' => 'A honlap SPIP segítségével készült',
	'sites_web' => 'Honlapok',
	'sous_rubriques' => 'Alsóbb rovatok',
	'suite' => 'folytatás',
	'sur_web' => 'Valahol a Weben',
	'syndiquer_rubrique' => 'A rovat szindikálása',
	'syndiquer_site' => 'Az egész honlap szindikálása',

	// T
	'texte_lettre_information' => 'Íme a honlap hírlevele',
	'texte_lettre_information_2' => 'Ez a hírlevél a cikkeket, ill. híreket összefoglalja azóta', # MODIF

	// V
	'ver_imprimer' => 'Nyomtatható változat',
	'voir_en_ligne' => 'Látni élőben',
];
